import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;

import javax.imageio.ImageIO;

//Lab5 (ImageProcessorTestOOP) 2018/4/3-5 OOP & Inheritance
public class ImageProcessorTestOOP {

	static String[] imageFiles = {"IMG1.jpg", "IMG2.jpg", "IMG3.jpg", "IMG4.jpg", "IMG5.jpg",
			"C:/JAVA/tacgun1.jpg", "C:/JAVA/tacgun2.jpg", "C:/JAVA/tacgun3.jpg", "C:/JAVA/tacgun4.jpg", "C:/JAVA/tacgun5.jpg", "C:/JAVA/tacgun6.jpg", "C:/JAVA/tacgun7.jpg"};
	
	// image process
	public static void process(ImageMode mode, String inputFile, String outputFile, boolean flag) {
		ImageProcessor ip = ImageProcessorFactory.getInstance(mode, new Photo(inputFile));
		if (ip == null) {
			System.out.println("Error! cannot get ImageProcessor"); 
			return;
		}
		if (flag) {
			ip.getAdditionalUserInput();
		}
		try {
			System.out.println(ip.getFormat());
			if (ip.getProcessedImg() != null) {
				boolean result = ImageIO.write(ip.getProcessedImg(), ip.getFormat(), new File(outputFile));
				if (result) System.out.println(mode + " : " + inputFile  + " is processed to " + outputFile + " successfully.");						
			}
		} catch (IOException e) {
			System.out.println("Error! cannot image process.");						
			e.printStackTrace();
		}
	}
	
	// image process (using default setting)
	public static void process(ImageMode mode, String inputFile) {
		String outputFile = null;		
		switch (mode) {
		case CONVERT:
			outputFile = Photo.getFullpathWithoutExt(inputFile) + "-out.png";
			break;
		case RESIZE:
			outputFile = Photo.getFullpathWithoutExt(inputFile) + "-thumb." + Photo.getExtension(inputFile);
			break;
		case ROTATE: 
			outputFile = Photo.getFullpathWithoutExt(inputFile) + "-rotate." + Photo.getExtension(inputFile);
			break;
		case GRAYSCALE:
			outputFile = Photo.getFullpathWithoutExt(inputFile) + "-gray." + Photo.getExtension(inputFile);
			break;
		case BLUR:
			outputFile = Photo.getFullpathWithoutExt(inputFile) + "-blur." + Photo.getExtension(inputFile);
			break;
		case BRIGHTNESS_ADJUST:
			outputFile = Photo.getFullpathWithoutExt(inputFile) + "-adjust." + Photo.getExtension(inputFile);
			break;
		case NEGATIVE: 
			outputFile = Photo.getFullpathWithoutExt(inputFile) + "-inv." + Photo.getExtension(inputFile);
			break;
		case EDGE_DETECT:
			outputFile = Photo.getFullpathWithoutExt(inputFile) + "-edge." + Photo.getExtension(inputFile);
			break;
		}
		process(mode, inputFile, outputFile, false);
	}
	
	// image process by user input
	public static void process() {
		ImageMode mode = UserInput.getImageMode("Please enter ImageMode [1.CONVERT 2.RESIZE 3.ROTATE 4.GRAYSCALE 5.BLUR 6.BRIGHTNESS_ADJUST]: ");
		String inputFile = UserInput.getString("Please enter [inputImageFilename]: ");
		String outputFile = UserInput.getString("Please enter [outputImageFilename]: ");
		process(mode, inputFile, outputFile, true);
	}
	
	public static void main(String[] args) {
		// 1. image process by ImageMode and inputFiles
		for (ImageMode mode : ImageMode.values()) {
			for (String inputFile : imageFiles) {
				process(mode, inputFile);
			}
		}
	
		// 2. image process by user input
		do {
			process();
		} while(!UserInput.getExitKey());
		
		// 3. your code
	}

}
